/*
 * (C) Copyright IBM Corp. 1999  All rights reserved.
 *
 * US Government Users Restricted Rights Use, duplication or
 * disclosure restricted by GSA ADP Schedule Contract with IBM Corp.
 *
 * The program is provided "as is" without any warranty express or
 * implied, including the warranty of non-infringement and the implied
 * warranties of merchantibility and fitness for a particular purpose.
 * IBM will not be liable for any damages suffered by you as a result
 * of using the Program. In no event will IBM be liable for any
 * special, indirect or consequential damages or lost profits even if
 * IBM has been advised of the possibility of their occurrence. IBM
 * will not be liable for any third party claims against you.
 */

package com.ibm.dom.util;

import org.w3c.dom.Attr;
import org.w3c.dom.CDATASection;
import org.w3c.dom.Comment;
import org.w3c.dom.Document;
import org.w3c.dom.DocumentFragment;
import org.w3c.dom.DocumentType;
import org.w3c.dom.Element;
import org.w3c.dom.Entity;
import org.w3c.dom.EntityReference;
import org.w3c.dom.Node;
import org.w3c.dom.Notation;
import org.w3c.dom.ProcessingInstruction;
import org.w3c.dom.Text;

/**
 *
 * <PRE>
 *     Node node = ...
 *     Visitor visitor = new FooVisitor(...);
 *     new TreeTraversal(visitor).traverse(node);
 * </PRE>
 *
 * @version Revision: %M% %I% %W% %Q%
 * @author TAMURA Kent &lt;tkent@jp.ibm.com&gt;
 * @see com.ibm.dom.util.TreeTraversal
 * @see com.ibm.xml.parser.Visitor
 */
public interface Visitor {
    public void visitElementPre(Element node) throws Exception;
    public void visitElementPost(Element node) throws Exception;
    public void visitAttributePre(Attr node) throws Exception;
    public void visitAttributePost(Attr node) throws Exception;
    public void visitTextPre(Text node) throws Exception;
    public void visitTextPost(Text node) throws Exception;
    public void visitCDATASectionPre(CDATASection node) throws Exception;
    public void visitCDATASectionPost(CDATASection node) throws Exception;
    public void visitEntityReferencePre(EntityReference node) throws Exception;
    public void visitEntityReferencePost(EntityReference node) throws Exception;
    public void visitEntityPre(Entity node) throws Exception;
    public void visitEntityPost(Entity node) throws Exception;
    public void visitProcessingInstructionPre(ProcessingInstruction node) throws Exception;
    public void visitProcessingInstructionPost(ProcessingInstruction node) throws Exception;
    public void visitCommentPre(Comment node) throws Exception;
    public void visitCommentPost(Comment node) throws Exception;
    public void visitDocumentPre(Document node) throws Exception;
    public void visitDocumentPost(Document node) throws Exception;
    public void visitDocumentTypePre(DocumentType node) throws Exception;
    public void visitDocumentTypePost(DocumentType node) throws Exception;
    public void visitDocumentFragmentPre(DocumentFragment node) throws Exception;
    public void visitDocumentFragmentPost(DocumentFragment node) throws Exception;
    public void visitNotationPre(Notation node) throws Exception;
    public void visitNotationPost(Notation node) throws Exception;
    public void visitUnknownPre(Node node) throws Exception;
    public void visitUnknownPost(Node node) throws Exception;
}
