/*
 * (C) Copyright IBM Corp. 1999  All rights reserved.
 *
 * US Government Users Restricted Rights Use, duplication or
 * disclosure restricted by GSA ADP Schedule Contract with IBM Corp.
 *
 * The program is provided "as is" without any warranty express or
 * implied, including the warranty of non-infringement and the implied
 * warranties of merchantibility and fitness for a particular purpose.
 * IBM will not be liable for any damages suffered by you as a result
 * of using the Program. In no event will IBM be liable for any
 * special, indirect or consequential damages or lost profits even if
 * IBM has been advised of the possibility of their occurrence. IBM
 * will not be liable for any third party claims against you.
 */

package com.ibm.xml.dsig;

import org.w3c.dom.*;
import java.util.*;

/**
 * @author YAGISHITA Kazuyo &lt;kazuyoy@jp.ibm.com&gt;
 */
class XDSAlgorithm implements XDSParameter {

    Document doc;
    Element domTree = null;
    String value;
    String type; // the parameter's type
    String algorithmType; // the algorithm's type
    String digestAlgorithmID = null;
    Vector parameters;

    XDSAlgorithm(Document doc, String type) {
        setDocument(doc);
        algorithmType = type;
        parameters = new Vector();
    }

    public void setDocument(Document doc) {
        this.doc = doc;
    }

    public void setDOMTree(Element el) {
        domTree = el;
    }

    public void setType(String type) {
        this.type = type;
    }

    public String getType() {
        return type;
    }

    void addParameter(XDSParameter p) {
        parameters.addElement(p);
    }

    public Element getDOMTree() {
        if ( domTree==null ) { 
            domTree = doc.createElement("dsig:Algorithm");
            domTree.setAttribute("type", algorithmType);
            Enumeration e = parameters.elements();
            while (e.hasMoreElements()) {
                Element el = doc.createElement("dsig:Parameter");
                XDSParameter p = (XDSParameter)e.nextElement();
                el.appendChild(p.getDOMTree());
                el.setAttribute("type", p.getType());
                domTree.appendChild(el);
            }
        }
        return (Element)domTree.cloneNode(true);
    }
}
