/*
 * (C) Copyright IBM Corp. 1999  All rights reserved.
 *
 * US Government Users Restricted Rights Use, duplication or
 * disclosure restricted by GSA ADP Schedule Contract with IBM Corp.
 *
 * The program is provided "as is" without any warranty express or
 * implied, including the warranty of non-infringement and the implied
 * warranties of merchantibility and fitness for a particular purpose.
 * IBM will not be liable for any damages suffered by you as a result
 * of using the Program. In no event will IBM be liable for any
 * special, indirect or consequential damages or lost profits even if
 * IBM has been advised of the possibility of their occurrence. IBM
 * will not be liable for any third party claims against you.
 */

package com.ibm.xml.dsig;

import org.w3c.dom.*;
import java.util.*;

/**
 * @author YAGISHITA Kazuyo &lt;kazuyoy@jp.ibm.com&gt;
 */
class XDSCertificates implements XDSNode {

    Document doc;
    Element domTree = null;
    Vector v;

    XDSCertificates(Document doc) {
        setDocument(doc);
        v = new Vector();
    }

    public void setDocument(Document doc) {
        this.doc = doc;
    }

    public void setDOMTree(Element el) {
        domTree = el;
    }

    void addCertificate(String type, String issuer, String number) {
        XDSCertificate c = new XDSCertificate(doc, type, issuer, number);
        v.addElement(c);
    }

    public Element getDOMTree() {
        if ( domTree==null ) { 
            domTree = doc.createElement("dsig:Certificates");
            Enumeration e = v.elements();
            while (e.hasMoreElements()) {
                domTree.appendChild(((XDSCertificate)e.nextElement()).getDOMTree());
            }
        }
        return (Element)domTree.cloneNode(true);
    }

}

class XDSCertificate implements XDSNode {
    
    Document doc;
    Element domTree = null;
    String type;
    XDSIssuerAndSerialNumber iasn;
    XDSValue value = null;
    XDSLocator locator = null;

    XDSCertificate(Document doc, String type, String issuer, String number) {
        setDocument(doc);
        this.type = type;
        iasn = new XDSIssuerAndSerialNumber(doc, issuer, number);
    }

    void setValue(byte[] value) {
        this.value = new XDSValue(doc, value);
        locator = null;
    }
  
    void setLocator(String locator) {
        this.locator = new XDSLocator(doc, locator);
        value = null;
    }
  
    public void setDocument(Document doc) {
        this.doc = doc;
    }

    public void setDOMTree(Element el) {
        domTree = el;
    }

    public Element getDOMTree() {
        if ( domTree==null ) { 
            domTree = doc.createElement("dsig:Certificate");
            domTree.setAttribute("type", type);
            domTree.appendChild(iasn.getDOMTree());
            if ( value != null ) {
                domTree.appendChild(value.getDOMTree());
            } else if ( locator != null ) {
                domTree.appendChild(locator.getDOMTree());
            }
        }
        return (Element)domTree.cloneNode(true);
    }
    
}
