/*
 * (C) Copyright IBM Corp. 1999  All rights reserved.
 *
 * US Government Users Restricted Rights Use, duplication or
 * disclosure restricted by GSA ADP Schedule Contract with IBM Corp.
 *
 * The program is provided "as is" without any warranty express or
 * implied, including the warranty of non-infringement and the implied
 * warranties of merchantibility and fitness for a particular purpose.
 * IBM will not be liable for any damages suffered by you as a result
 * of using the Program. In no event will IBM be liable for any
 * special, indirect or consequential damages or lost profits even if
 * IBM has been advised of the possibility of their occurrence. IBM
 * will not be liable for any third party claims against you.
 */

package com.ibm.xml.dsig;

import org.w3c.dom.*;

/**
 * @author YAGISHITA Kazuyo &lt;kazuyoy@jp.ibm.com&gt;
 */
class XDSPackageResource implements XDSResource {

    Document doc;
    Element domTree = null;
    XDSContentType contentType = null;
    XDSValue value;
    String dsigeval = null;
    String id = null;

    XDSPackageResource(Document doc, byte[] value) {
        setDocument(doc);
        this.value = new XDSValue(doc, value);
    }
    
    XDSPackageResource(Document doc, byte[] value, String dsigeval, String id) {
        setDocument(doc);
        this.value = new XDSValue(doc, value);
        this.dsigeval = dsigeval;
        this.id = id;
    }

    XDSPackageResource(Document doc, Element el) {
        setDocument(doc);
        this.value = new XDSValue(doc, el);
    }

    XDSPackageResource(Document doc, Element el, String dsigeval, String id) {
        setDocument(doc);
        this.value = new XDSValue(doc, el);
        this.dsigeval = dsigeval;
        this.id = id;
    }

    public void setDocument(Document doc) {
        this.doc = doc;
    }

    public void setDOMTree(Element el) {
        domTree = el;
    }
    
    public Element getDOMTree() {
        if ( domTree==null ) { 
            domTree = doc.createElement("dsig:Package");
            if ( contentType != null ) domTree.appendChild(contentType.getDOMTree());
            domTree.appendChild(value.getDOMTree());
            if ( dsigeval != null ) domTree.setAttribute("dsig:eval", dsigeval);
            if ( id != null ) domTree.setAttribute("id", id);
        }
        return (Element)domTree.cloneNode(true);
    }
    
    public void setType(String type) {
        contentType = new XDSContentType(doc, type);
    }

    public String getType(){
        return contentType.type;
    }

    public void setEncoding(String encoding) {
        value.encoding = encoding;
    }

    public String getEncoding(){
        return value.encoding;
    }
    
}
