/*
 * (C) Copyright IBM Corp. 1999  All rights reserved.
 *
 * US Government Users Restricted Rights Use, duplication or
 * disclosure restricted by GSA ADP Schedule Contract with IBM Corp.
 *
 * The program is provided "as is" without any warranty express or
 * implied, including the warranty of non-infringement and the implied
 * warranties of merchantibility and fitness for a particular purpose.
 * IBM will not be liable for any damages suffered by you as a result
 * of using the Program. In no event will IBM be liable for any
 * special, indirect or consequential damages or lost profits even if
 * IBM has been advised of the possibility of their occurrence. IBM
 * will not be liable for any third party claims against you.
 */

package com.ibm.xml.dsig;

import org.w3c.dom.*;
import java.util.*;

/**
 * @author YAGISHITA Kazuyo &lt;kazuyoy@jp.ibm.com&gt;
 */
class XDSSignatures implements XDSNode {

    Document doc;
    Element domTree = null;
    Vector v;

    XDSSignatures(Document doc) {
        setDocument(doc);
        v = new Vector();
    }
    
    public void setDocument(Document doc) {
        this.doc = doc;
    }
    
    public void setDOMTree(Element el) {
        domTree = el;
    }
    
    void addSignature(XDSManifest manifest, XDSValue value) {
        XDSSignature s = new XDSSignature(doc, manifest, value);
        v.addElement(s);
    }
    
    public Element getDOMTree() {
        if ( domTree==null ) { 
            domTree = doc.createElement("dsig:Signatures");
            Enumeration e = v.elements();
            while (e.hasMoreElements()) {
                domTree.appendChild(((XDSSignature)e.nextElement()).getDOMTree());
            }
        }
        return (Element)domTree.cloneNode(true);
    }
}

class XDSSignature implements XDSNode {

    Document doc;
    Element domTree = null;
    XDSManifest manifest;
    String dsigeval = null;
    String id = null;
    XDSValue value;

    XDSSignature(Document doc, XDSManifest manifest, XDSValue value) {
        setDocument(doc);
        this.manifest = manifest;
        this.value = value;
    }
    
    public void setDocument(Document doc) {
        this.doc = doc;
    }

    public void setDOMTree(Element el) {
        domTree = el;
    }

    public Element getDOMTree() {
        if ( domTree==null ) { 
            domTree = doc.createElement("dsig:Signature");
            if ( dsigeval != null ) domTree.setAttribute("dsig:eval", dsigeval);
            if ( id != null ) domTree.setAttribute("id", id);
            domTree.appendChild(manifest.getDOMTree());
            domTree.appendChild(value.getDOMTree());
        }
        return (Element)domTree.cloneNode(true);
    }
    
}
