/*
 * (C) Copyright IBM Corp. 1999  All rights reserved.
 *
 * US Government Users Restricted Rights Use, duplication or
 * disclosure restricted by GSA ADP Schedule Contract with IBM Corp.
 *
 * The program is provided "as is" without any warranty express or
 * implied, including the warranty of non-infringement and the implied
 * warranties of merchantibility and fitness for a particular purpose.
 * IBM will not be liable for any damages suffered by you as a result
 * of using the Program. In no event will IBM be liable for any
 * special, indirect or consequential damages or lost profits even if
 * IBM has been advised of the possibility of their occurrence. IBM
 * will not be liable for any third party claims against you.
 */

package com.ibm.xml.dsig;

import org.w3c.dom.*;
import com.ibm.dom.util.DOMDuplicator;
import sun.misc.BASE64Encoder;

/**
 * @author YAGISHITA Kazuyo &lt;kazuyoy@jp.ibm.com&gt;
 */
class XDSValue implements XDSNode {

    Document doc;
    Element domTree = null;
    byte[] value = null;
    Element el = null;
    String encoding = "none";

    XDSValue(Document doc) {
        setDocument(doc);
    }

    XDSValue(Document doc, byte[] value) {
        setDocument(doc);
        this.value = value;
    }
    
    XDSValue(Document doc, byte[] value, String encoding) {
        setDocument(doc);
        this.value = value;
        this.encoding = encoding;
    }
    
    XDSValue(Document doc, Element el) {
        setDocument(doc);
        this.el = el;
    }
    
    XDSValue(Document doc, Element el, String encoding) {
        setDocument(doc);
        this.el = el;
        this.encoding = encoding;
    }
    
    public void setDocument(Document doc) {
        this.doc = doc;
    }
    
    public void setDOMTree(Element el) {
        domTree = el;
    }
    
    public Element getDOMTree() {
        if ( domTree==null ) { 
            domTree = doc.createElement("dsig:Value");
            if ( value != null ) {
                if ( encoding.equals("base64") ) {
                    domTree.setAttribute("encoding", encoding);
                    domTree.appendChild(doc.createTextNode(getBase64Digest(value)));
                } else {
                    domTree.setAttribute("encoding", "none");
                    domTree.appendChild(doc.createTextNode(new String(value)));
                }
            } else if ( el != null ) {
                domTree.appendChild(DOMDuplicator.cloneNode(doc, el));
            }
        }
        return (Element)domTree.cloneNode(true);
    }

    /**
     * Returns base64 (String) representation of the hash value.
     */
    final String S_BASE64CHAR 
    = "ABCDEFGHIJKLMNOPQRSTUVWXYZabcdefghijklmnopqrstuvwxyz0123456789+/";
    final char S_BASE64PAD = '=';

    String getBase64Digest(byte[] b) {
	return encode(b, 0, b.length);
    }

    String encode(byte[] ab, int off, int len) {
	if (len <= 0)  return "";
	if (len <= 3) {
	    int i;
	    char[] ach = new char[4];
	    switch (len) {
	      case 1:
		i = ab[off]&0xff;
		ach[0] = S_BASE64CHAR.charAt(i>>2);
		ach[1] = S_BASE64CHAR.charAt((i<<4)&0x3f);
		ach[2] = S_BASE64PAD;
		ach[3] = S_BASE64PAD;
		break;
	      case 2:
		i = ((ab[off]&0xff)<<8)+(ab[off+1]&0xff);
		ach[0] = S_BASE64CHAR.charAt(i>>10);
		ach[1] = S_BASE64CHAR.charAt((i>>4)&0x3f);
		ach[2] = S_BASE64CHAR.charAt((i<<2)&0x3f);
		ach[3] = S_BASE64PAD;
		break;
	      case 3:
		i = ((ab[off]&0xff)<<16)
		    +((ab[off+1]&0xff)<<8)
                    +(ab[off+2]&0xff);
		ach[0] = S_BASE64CHAR.charAt(i>>18);
		ach[1] = S_BASE64CHAR.charAt((i>>12)&0x3f);
		ach[2] = S_BASE64CHAR.charAt((i>>6)&0x3f);
		ach[3] = S_BASE64CHAR.charAt(i&0x3f);
		break;
	    }
	    return new String(ach);
	} else {
	    return encode(ab, off, 3)+encode(ab, off+3, len-3);
	}
    }
    
}
