/*
 * (C) Copyright IBM Corp. 1999  All rights reserved.
 *
 * US Government Users Restricted Rights Use, duplication or
 * disclosure restricted by GSA ADP Schedule Contract with IBM Corp.
 *
 * The program is provided "as is" without any warranty express or
 * implied, including the warranty of non-infringement and the implied
 * warranties of merchantibility and fitness for a particular purpose.
 * IBM will not be liable for any damages suffered by you as a result
 * of using the Program. In no event will IBM be liable for any
 * special, indirect or consequential damages or lost profits even if
 * IBM has been advised of the possibility of their occurrence. IBM
 * will not be liable for any third party claims against you.
 */

package com.ibm.xml.dsig;

import org.w3c.dom.*;
import java.util.*;

/**
 * @author YAGISHITA Kazuyo &lt;kazuyoy@jp.ibm.com&gt;
 */
public class XMLDSig {

  private Document doc; // factory for DOM
  private Algorithm da = null; // DigestAlgorithm
  private PackageResource pr = null; // Package
  private Signatures signatures; // Signatures
  private Certificates certificates = null; // Certificates
  
  public XMLDSig() {
    signatures = new Signatures();
  }

  /**
    * Set document.  This document is used as a factory for creating
    * nodes.
    */
  public void setDocument(Document doc) {
    this.doc = doc;
    signatures.setDocument(doc);
  }

  /**
    * Set package.
    */
  public void setPackage(Algorithm da, PackageResource pr) {
    this.da = da;
    this.pr = pr;
  }

  /**
    * Add a new signature
    */
  public void addSignature(Signature s) {
    signatures.addSignature(s);
  }

  /**
    * Add a new certificate
    */
  public void addCertificate(Certificate c) {
    if ( certificates == null) {
      certificates = new Certificates();
      certificates.setDocument(doc);
    }
    certificates.addCertificate(c);
  }

  /**
    * Create a signed Document
    */
  public Element getDSigDocument() {
    Element el = doc.createElement("dsig:Document");
    el.setAttribute("xmlns:dsig", "http://www.ibm.com/xml/dsig/");
    if ((da != null) && (pr != null)) {
      Element e = doc.createElement("dsig:DigestAlgorithm");
      e.setAttribute("id", da.getID());
      e.appendChild(da.getDOMTree());
      el.appendChild(e);
      el.appendChild(pr.getDOMTree()); 
    }
    el.appendChild(signatures.getDOMTree());
    if ( certificates != null ) el.appendChild(certificates.getDOMTree());
    return el;
  }

}
